@@ -25,6 +25,10 @@ from .utils.log import log
 INSTRUMENTING_LIBRARY_VERSION = '0.30b1'
 
 
+class NoPlanException(BaseException):
+    pass
+
+
 @log
 def add_quote_to_value_of_type_string(value):
     if isinstance(value, str):
@@ -184,13 +188,11 @@ class MetisSQLAlchemyInstrumentor(SQLAlchemyInstrumentor):
                                 parameters,
                             )
                             res = new_cursor.fetchall()
-                        except Exception:
-                            res = None
                         finally:
                             new_cursor.close()
 
                         if not res:
-                            raise Exception(f"No plan found for query:\n{statement}")
+                            raise NoPlanException(f"Query: {interpolated_statement}")
                         current_span.set_attribute(
                             METIS_PLAN_SPAN_ATTRIBUTE,
                             json.dumps(res[0][0][0]),
