@@ -6,6 +6,8 @@ from distutils.util import strtobool
 from socket import gethostname
 from typing import Optional
 
+import pkg_resources
+import sentry_sdk
 from opentelemetry import trace
 from opentelemetry.instrumentation.flask import FlaskInstrumentor
 from opentelemetry.sdk.resources import SERVICE_NAME, Resource, SERVICE_VERSION, Attributes
@@ -38,13 +40,6 @@ os.environ[
     "OTEL_INSTRUMENTATION_HTTP_CAPTURE_HEADERS_SERVER_RESPONSE"
 ] = "content-type,content-length,custom_request_header"
 
-EXPLAIN_SUPPORTED_STATEMENTS = (
-    "SELECT",
-    "INSERT",
-    "UPDATE",
-    "DELETE",
-)
-
 
 @log
 def add_quote_to_value_of_type_string(value):
@@ -54,25 +49,6 @@ def add_quote_to_value_of_type_string(value):
     return value
 
 
-@log
-def fix_sql_query(sql, params):
-    """without the fix the query is not working because string is not quoted"""
-    try:
-        fixed_param = params
-        if isinstance(params, dict):
-            fixed_param = {
-                key: add_quote_to_value_of_type_string(value)
-                for key, value in params.items()
-            }
-
-        return sql % fixed_param
-    except Exception:
-        # TODO: Add sentry call here and verify that we're aware for exceptions
-        # Ariksa has problem here, we dont know what the
-        logger.debug("Couldn't bind param")
-        return sql
-
-
 @log
 def _normalize_vendor(vendor):
     """Return a canonical name for a type of database."""
@@ -93,6 +69,7 @@ def _build_resource(
         service_name: str,
         service_version: str,
         resource_tags: Attributes,
+        sentry_logger: Optional[sentry_sdk.Hub],
 ) -> Resource:
     attrs = {}
 
@@ -104,7 +81,9 @@ def _build_resource(
     try:
         attrs["host.name"] = gethostname()
     except Exception as e:
-        logger.exception("Couldn't get hostname for service", exc_info=e)
+        if sentry_logger is not None:
+            sentry_logger.capture_exception(e)
+    attrs['metis.sdk.version'] = pkg_resources.get_distribution('sqlalchemycollector').version
 
     if resource_tags:
         attrs.update(_convert_items_to_metis_tags(resource_tags))
@@ -129,16 +108,31 @@ def setup(
         plan_collection_option: Optional[PlanCollectType] = PlanCollectType.ESTIMATED,
         file_name: Optional[str] = None,
         api_key: Optional[str] = None,
-        dsn: Optional[str] = None):
+        dsn: Optional[str] = None,
+        report_errors: bool = True):
     _is_metis_instrumentation_enable = strtobool(os.getenv(METIS_INSTRUMENTATION_STR, 'true'))
     if not _is_metis_instrumentation_enable:
         logging.debug("Metis instrumentation is disabled")
         return
 
+    if api_key and report_errors:
+        sentry_logger = sentry_sdk.Hub(sentry_sdk.Client(
+            dsn='https://f4732683eb3a40ab9e5a5d4033b246e0@o1173646.ingest.sentry.io/6271090',
+            traces_sample_rate=1.0,
+            with_locals=False,
+            request_bodies="never",
+            auto_session_tracking=False,
+            release=__version__,
+        ))
+        sentry_logger.scope.set_user({'id': api_key})
+    else:
+        sentry_logger = None
+
     metis_interceptor = MetisInstrumentor(service_name,
                                           service_version=service_version,
                                           resource_tags=resource_tags,
-                                          plan_collection_option=plan_collection_option)
+                                          plan_collection_option=plan_collection_option,
+                                          sentry_logger=sentry_logger)
 
     metis_interceptor.set_exporters(file_name, api_key, dsn)
 
@@ -161,14 +155,16 @@ class MetisInstrumentor(metaclass=SingletonMeta):
                  service_version: Optional[str] = None,
                  resource_tags: Optional[Attributes] = None,
                  plan_collection_option: Optional[PlanCollectType] = PlanCollectType.ESTIMATED,
+                 sentry_logger: Optional[sentry_sdk.Hub] = None,
                  ):
         self.api_app_instance = None
         self.set_exporters_once = Once()
         self.sqlalchemy_instrumentor = None
         self.api_instrumentor = None
         self.plan_collection_option = plan_collection_option
+        self.sentry_logger = sentry_logger
 
-        resource = _build_resource(service_name, service_version, resource_tags)
+        resource = _build_resource(service_name, service_version, resource_tags, sentry_logger)
 
         self.tracer_provider = TracerProvider(sampler=ALWAYS_ON,
                                               resource=resource)
@@ -202,7 +198,7 @@ class MetisInstrumentor(metaclass=SingletonMeta):
         if bool(dsn) != bool(api_key):
             raise ValueError("Both endpoint and api_key must be provided")
         if dsn is not None:
-            self._add_processor(BatchSpanProcessor(MetisRemoteExporter(dsn, api_key)))
+            self._add_processor(BatchSpanProcessor(MetisRemoteExporter(dsn, api_key, self.sentry_logger)))
 
         if strtobool(os.getenv("DEBUG", 'False')):
             self._add_processor(BatchSpanProcessor(ConsoleSpanExporter()))
@@ -212,7 +208,7 @@ class MetisInstrumentor(metaclass=SingletonMeta):
         self.tracer_provider.add_span_processor(processor)
 
     @log
-    def instrument_app(self, app, engine):
+    def instrument_app(self, app, engine, excluded_urls=None):
         @log
         def request_hook(
                 span: Span,
@@ -231,6 +227,7 @@ class MetisInstrumentor(metaclass=SingletonMeta):
             self.api_app_instance,
             tracer_provider=self.tracer_provider,
             request_hook=request_hook,
+            excluded_urls=excluded_urls,
         )
 
         if hasattr(engine, 'sync_engine') and engine.sync_engine is not None:
@@ -239,6 +236,7 @@ class MetisInstrumentor(metaclass=SingletonMeta):
 
         if self.sqlalchemy_instrumentor is None:
             self.sqlalchemy_instrumentor = MetisSQLAlchemyInstrumentor()
+            self.sqlalchemy_instrumentor.sentry_logger = self.sentry_logger
 
         self.sqlalchemy_instrumentor.instrument(
             engine=engine,
